@@ -1,8 +1,8 @@
-from typing import List
+from typing import List, Optional
 
 from pydantic import BaseModel, Field
 
-from dbt_dry_run.models.manifest import Node, NodeConfig, NodeDependsOn
+from dbt_dry_run.models.manifest import Node, NodeConfig, NodeDependsOn, NodeMeta
 from dbt_dry_run.scheduler import ManifestScheduler
 
 A_SQL_QUERY = "SELECT * FROM `foo`"
@@ -20,6 +20,7 @@ class SimpleNode(BaseModel):
     compiled_code: str = A_SQL_QUERY
     original_file_path: str = f"test123.sql"
     root_path: str = "/home/"
+    meta: Optional[NodeMeta]
 
     def to_node(self) -> Node:
         depends_on = NodeDependsOn(
@@ -39,6 +40,8 @@ class SimpleNode(BaseModel):
             resource_type=resource_type,
             original_file_path=self.original_file_path,
             root_path=self.root_path,
+            columns=dict(),
+            meta=self.meta,
         )
 
 
